# Remotsy API [![Build Status](https://travis-ci.org/jorgecis/RemotsyLib.svg?branch=master)](https://travis-ci.org/jorgecis/RemotsyLib)
[![Coverage Status](https://coveralls.io/repos/github/jorgecis/RemotsyLib/badge.svg?branch=master)](https://coveralls.io/github/jorgecis/RemotsyLib?branch=master)
